summaryrefslogtreecommitdiffstats
path: root/src/kmplayer_smil.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/kmplayer_smil.h')
-rw-r--r--src/kmplayer_smil.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/kmplayer_smil.h b/src/kmplayer_smil.h
index 12247f5..ab34703 100644
--- a/src/kmplayer_smil.h
+++ b/src/kmplayer_smil.h
@@ -61,7 +61,7 @@ class TextRuntimePrivate;
/*
* Event signaled before the actual starting takes place. Use by SMIL::Excl
- * to stop possible other tqchildren
+ * to stop possible other children
*/
class ToBeStartedEvent : public Event {
public:
@@ -444,15 +444,15 @@ public:
/**
* repaints region, calls scheduleRepaint(x,y,w,h) on view
*/
- void tqrepaint ();
- void tqrepaint (const SRect & rect);
+ void repaint ();
+ void repaint (const SRect & rect);
/**
* calculate the relative x,y,w,h on the child region elements
* given this element's w and h value
* and child's left/top/right/width/height/bottom attributes
*/
virtual void updateDimensions ();
- void boundsUpdate (); // recalculates and tqrepaint old and new bounds
+ void boundsUpdate (); // recalculates and repaint old and new bounds
virtual Surface *surface ();
SurfacePtrW region_surface;
@@ -521,7 +521,7 @@ public:
};
/**
- * Represents a regPoint element for tqalignment inside regions
+ * Represents a regPoint element for alignment inside regions
*/
class KMPLAYER_NO_EXPORT RegPoint : public Element {
public:
@@ -656,7 +656,7 @@ protected:
};
/**
- * A Par represents parallel processing of all its tqchildren
+ * A Par represents parallel processing of all its children
*/
class KMPLAYER_NO_EXPORT Par : public GroupBase {
public:
@@ -668,7 +668,7 @@ public:
};
/**
- * A Seq represents sequential processing of all its tqchildren
+ * A Seq represents sequential processing of all its children
*/
class KMPLAYER_NO_EXPORT Seq : public GroupBase {
public:
@@ -691,7 +691,7 @@ public:
};
/**
- * An Excl represents exclusive processing of one of its tqchildren
+ * An Excl represents exclusive processing of one of its children
*/
class KMPLAYER_NO_EXPORT Excl : public GroupBase {
public:
@@ -780,7 +780,7 @@ public:
Surface *surface ();
void resetSurface ();
SRect calculateBounds ();
- void boundsUpdate (); // recalculates and tqrepaint old and new bounds
+ void boundsUpdate (); // recalculates and repaint old and new bounds
virtual void parseParam (const TrieString & name, const TQString & value);
virtual bool handleEvent (EventPtr event);
NodeRefListPtr listeners (unsigned int event_id);